@@ -1,5 +1,5 @@
 /*
- *  $Id: dlpi.c,v 1.1.1.1 1999/05/03 04:00:37 dugsong Exp $
+ *  $Id: dlpi.c,v 1.15 1999/05/28 17:36:45 route Exp $
  *
  *  libnet
  *  dlpi.c - dlpi routines
@@ -41,9 +41,6 @@
 #include <sys/bufmod.h>
 #endif
 #include <sys/dlpi.h>
-#ifdef HAVE_SYS_DLPI_EXT_H
-#include <sys/dlpi_ext.h>
-#endif
 #ifdef HAVE_HPUX9
 #include <sys/socket.h>
 #endif
@@ -685,11 +682,11 @@ write_link_layer(struct link_int *l, const u_char *device, u_char *buf, int len)
 
     /* Send it */
     ctl.len = DL_UNITDATA_REQ_SIZE + sizeof (struct EnetHeaderInfo);
-    ctl.buf = (char*) dlp;
-    data.maxlen = len;
+    ctl.buf = (char *)dlp;
 
+    data.maxlen = len;
     data.len    = len;
-    data.buf    = (u_char *)buf;
+    data.buf    = buf;
 
     c = putmsg(l->fd, NULL, &data, 0);
     if (c == -1)
@@ -703,10 +700,6 @@ write_link_layer(struct link_int *l, const u_char *device, u_char *buf, int len)
 }
 
 
-/*
- *  libpcap provides a way to get net and mask, but not this
- *  Derrick J Brashear <shadow@dementia.org>
- */
 struct ether_addr *
 get_hwaddr(struct link_int *l, const u_char *device, char *ebuf)
 {
@@ -722,16 +715,18 @@ get_hwaddr(struct link_int *l, const u_char *device, char *ebuf)
     if (send_request(l->fd, (char *)dlp, DL_PHYS_ADDR_REQ_SIZE, "physaddr",
                     ebuf, 0) < 0)
     {
+        sprintf(ebuf, "get_hwaddr %s", strerror(errno));
         return (NULL);
     }
     if (recv_ack(l->fd, DL_PHYS_ADDR_ACK_SIZE, "physaddr", (char *)dlp, ebuf)
         < 0)
     {
+        sprintf(ebuf, "get_hwaddr %s", strerror(errno));
         return (NULL);
     }
 
-    eap = (struct ether_addr *) ((char *) dlp +
-                                 dlp->physaddr_ack.dl_addr_offset);
+    eap = (struct ether_addr *)
+        ((char *) dlp + dlp->physaddr_ack.dl_addr_offset);
     return (eap);
 }   
 
