@@ -69,6 +69,7 @@ free_tcp (struct tcp_stream *a_tcp)
 //  free (a_tcp);
   a_tcp->next_free = free_streams;
   free_streams = a_tcp;
+  tcp_num--;
 }
 
 
@@ -84,7 +85,6 @@ add_new_tcp (int hash_index, struct tuple4 addr, struct tcphdr *this_tcphdr)
       for (i = tcp_oldest->listeners; i; i = i->next)
 	(i->item) (tcp_oldest, &i->data);
       free_tcp (tcp_oldest);
-      tcp_num--;
       nids_params.syslog (NIDS_WARN_TCP, NIDS_WARN_TCP_TOOMUCH, ugly_iphdr, this_tcphdr);
     }
   a_tcp = free_streams;
@@ -648,13 +648,13 @@ tcp_init (int size)
 {
   int tmp, i;
 
-  tcp_stream_table_size = nids_params.n_hosts;
+  tcp_stream_table_size = nids_params.n_tcp_streams;
   tcp_stream_table = malloc (tcp_stream_table_size * sizeof (char *));
   memset (tcp_stream_table, 0, tcp_stream_table_size * sizeof (char *));
   tmp = tcp_stream_table_size;
   hash_deg = 32;
   //computing ceiling of binary logarithm of tcp_stream_table_size
-  while (!(0x800000 & tmp))
+  while (!(0x80000000 & tmp))
     {
       hash_deg--;
       tmp <<= 1;
